==> laravel-rest-api-query-builder-0.0.2.tgz: package/tests/dummy/data/simple-object.js <==
export const Post = {
    "id": "1",
    "type": "posts",
    "slug": "voluptates-laborum-non-voluptatem-ducimus-veniam-et",
    "title": "Voluptates laborum non voluptatem ducimus veniam et.",
    "subtitle": "Cumque aut laudantium repudiandae rem repellendus voluptatem. Sunt ipsa eum ea molestias.",
    "body": "Est quod itaque suscipit quidem dolor dolores velit. Nihil voluptas placeat ex consequatur quasi.\n\nEst nulla cupiditate ad beatae rerum veritatis vel. Quia ut doloribus consequatur porro. Eligendi sit et dignissimos qui voluptatem magnam mollitia labore.\n\nLibero saepe praesentium et sed. Exercitationem error rerum sit inventore provident laborum. Fuga pariatur dolor reiciendis. Quibusdam corrupti commodi ut quo non laboriosam quia. Nihil sit iste sit optio voluptas repellendus exercitationem.",
    "published_at": "2018-01-25",
    "links": {
        "self": "https:\/\/sarala-demo.app\/api\/posts\/1"
    },
    "meta": {
        "copyright": "Copyright 2018 Example Corp."
    }
};

export const PaginatedPostsList = {
    "data_collection": true,
    "data": [
        {
            "id": "1",
            "type": "posts",
            "links": {
                "self": "https:\/\/sarala-demo.app\/api\/posts\/1"
            },
            "slug": "voluptates-laborum-non-voluptatem-ducimus-veniam-et",
            "title": "Voluptates laborum non voluptatem ducimus veniam et.",
            "subtitle": "Cumque aut laudantium repudiandae rem repellendus voluptatem. Sunt ipsa eum ea molestias.",
            "body": "Est quod itaque suscipit quidem dolor dolores velit. Nihil voluptas placeat ex consequatur quasi.\n\nEst nulla cupiditate ad beatae rerum veritatis vel. Quia ut doloribus consequatur porro. Eligendi sit et dignissimos qui voluptatem magnam mollitia labore.\n\nLibero saepe praesentium et sed. Exercitationem error rerum sit inventore provident laborum. Fuga pariatur dolor reiciendis. Quibusdam corrupti commodi ut quo non laboriosam quia. Nihil sit iste sit optio voluptas repellendus exercitationem.",
            "published_at": "2018-01-25"
        },
        {
            "id": "2",
            "type": "posts",
            "links": {
                "self": "https:\/\/sarala-demo.app\/api\/posts\/2"
            },
            "slug": "atque-nobis-maxime-voluptatem-voluptatem-labore",
            "title": "Atque nobis maxime voluptatem voluptatem labore.",
            "subtitle": "Eum sit aut ducimus dicta possimus. Quam voluptas consequatur aspernatur laborum corporis.",
            "body": "Omnis non sit voluptatem perspiciatis harum. Ad itaque dolores sunt distinctio. Sequi id et aliquid consequatur natus eum illum. Voluptatem natus velit vel et officiis molestiae molestiae voluptatem.\n\nCum voluptatem quam voluptatum dolores dolor corporis. Et fugiat expedita eum nisi corrupti voluptas. Magnam molestiae alias nulla dolores soluta nam. Est aut nihil tempore sed.\n\nVoluptas iusto eveniet adipisci alias voluptas ab. Fugit praesentium distinctio porro iure sit. Dolorem sit amet ab enim dolores mollitia sequi.",
            "published_at": "2018-02-01"
        },
        {
            "id": "3",
            "type": "posts",
            "links": {
                "self": "https:\/\/sarala-demo.app\/api\/posts\/3"
            },
            "slug": "velit-excepturi-et-eius",
            "title": "Velit excepturi et eius.",
            "subtitle": "Autem culpa dolores quis beatae rem. Qui rerum pariatur sed dolorem est rem pariatur.",
            "body": "Deleniti facere sed amet rerum. Fuga ut quia et et maxime. Ut deleniti quibusdam dolores pariatur et sit et.\n\nIpsum eos esse voluptas nihil maxime itaque. Sed rem repudiandae praesentium aut ullam. Dolores veniam qui et iusto.\n\nNostrum earum sed nobis aut accusantium velit. Corporis doloribus sit dicta. Rem odit non illum dolores. Distinctio dolores et qui sapiente est fugiat error. Voluptatum harum ullam et.",
            "published_at": "2018-01-17"
        },
        {
            "id": "4",
            "type": "posts",
            "links": {
                "self": "https:\/\/sarala-demo.app\/api\/posts\/4"
            },
            "slug": "ipsum-ut-ut-dolorem-qui-voluptas",
            "title": "Ipsum ut ut dolorem qui voluptas.",
            "subtitle": "Id enim dolores veniam consequatur. Sit perspiciatis deserunt ut reiciendis voluptas.",
            "body": "Reprehenderit esse porro sed quae voluptates et. Rem omnis et qui nemo. Sed mollitia voluptatem vero aspernatur ut nobis porro.\n\nVoluptas voluptatem molestiae tempora autem. Repudiandae dolor qui nisi. Saepe sunt veniam perferendis consequatur quisquam quo id.\n\nIusto ut libero ipsa quia sed unde architecto. Aliquam quia sint qui earum et. Architecto et accusamus sed impedit doloremque.",
            "published_at": "2018-02-27"
        }
    ],
    "meta": {
        "pagination": {
            "total": 10,
            "count": 4,
            "per_page": 4,
            "current_page": 1,
            "total_pages": 3
        }
    },
    "links": {
        "self": "https:\/\/sarala-demo.app\/api\/posts?=1",
        "first": "https:\/\/sarala-demo.app\/api\/posts?=1",
        "next": "https:\/\/sarala-demo.app\/api\/posts?=2",
        "last": "https:\/\/sarala-demo.app\/api\/posts?=3"
    }
};

export const PostWithAllNesterRelations = {
    "id": "1",
    "type": "posts",
    "slug": "voluptates-laborum-non-voluptatem-ducimus-veniam-et",
    "title": "Voluptates laborum non voluptatem ducimus veniam et.",
    "subtitle": "Cumque aut laudantium repudiandae rem repellendus voluptatem. Sunt ipsa eum ea molestias.",
    "body": "Est quod itaque suscipit quidem dolor dolores velit. Nihil voluptas placeat ex consequatur quasi.\n\nEst nulla cupiditate ad beatae rerum veritatis vel. Quia ut doloribus consequatur porro. Eligendi sit et dignissimos qui voluptatem magnam mollitia labore.\n\nLibero saepe praesentium et sed. Exercitationem error rerum sit inventore provident laborum. Fuga pariatur dolor reiciendis. Quibusdam corrupti commodi ut quo non laboriosam quia. Nihil sit iste sit optio voluptas repellendus exercitationem.",
    "published_at": "2018-01-25",
    "relationships": [
        "author",
        "tags",
        "comments"
    ],
    "author": {
        "data": {
            "email": "margret06@example.com",
            "id": "1",
            "links": {
                "self": "https://sarala-demo.app/api/users/1"
            },
            "name": "Heidi Hintz Jr.",
            "type": "users"
        },
        "links": {
            "related": "https://sarala-demo.app/api/posts/1/author",
            "self": "https://sarala-demo.app/api/posts/1/relationships/author"
        }
    },
    "comments": {
        "data": [
            {
                "author": {
                    "data": {
                        "email": "reynold11@example.org",
                        "id": "11",
                        "links": {
                            "self": "https://sarala-demo.app/api/users/11"
                        },
                        "name": "Abdullah Grant",
                        "type": "users"
                    },
                    "links": {
                        "related": "https://sarala-demo.app/api/comments/1/author",
                        "self": "https://sarala-demo.app/api/comments/1/relationships/author"
                    }
                },
                "body": "Nihil et quia tempora est quae nostrum velit ipsum. Nemo et aut maxime id.",
                "created_at": "2018-02-10",
                "id": "1",
                "links": {
                    "self": "https://sarala-demo.app/api/comments/1"
                },
                "relationships": [
                    "author"
                ],
                "type": "comments"
            },
            {
                "author": {
                    "data": {
                        "email": "manuela76@example.net",
                        "id": "12",
                        "links": {
                            "self": "https://sarala-demo.app/api/users/12"
                        },
                        "name": "Mr. Nathanial Maggio",
                        "type": "users"
                    },
                    "links": {
                        "related": "https://sarala-demo.app/api/comments/2/author",
                        "self": "https://sarala-demo.app/api/comments/2/relationships/author"
                    }
                },
                "body": "Sint quaerat et ut delectus ratione id alias ab. Aut molestias ut dolores maiores ratione deserunt.",
                "created_at": "2018-02-10",
                "id": "2",
                "links": {
                    "self": "https://sarala-demo.app/api/comments/2"
                },
                "relationships": [
                    "author"
                ],
                "type": "comments"
            }
        ],
        "data_collection": true,
        "links": {
            "related": "https://sarala-demo.app/api/posts/1/comments",
            "self": "https://sarala-demo.app/api/posts/1/relationships/comments"
        }
    },
    "tags": {
        "data": [
            {
                "id": "1",
                "links": {
                    "self": "https://sarala-demo.app/api/tags/1"
                },
                "name": "voluptates",
                "type": "tags"
            },
            {
                "id": "15",
                "links": {
                    "self": "https://sarala-demo.app/api/tags/15"
                },
                "name": "dolorum",
                "type": "tags"
            }
        ],
        "data_collection": true,
        "links": {
            "related": "https://sarala-demo.app/api/posts/1/tags",
            "self": "https://sarala-demo.app/api/posts/1/relationships/tags"
        }
    },
    "links": {
        "self": "https://sarala-demo.app/api/posts/1"
    }
};

==> laravel-rest-api-query-builder-0.0.4.tgz: package/tests/dummy/data/simple-object.js <==
export const Post = {
    "id": "1",
    "type": "posts",
    "slug": "voluptates-laborum-non-voluptatem-ducimus-veniam-et",
    "title": "Voluptates laborum non voluptatem ducimus veniam et.",
    "subtitle": "Cumque aut laudantium repudiandae rem repellendus voluptatem. Sunt ipsa eum ea molestias.",
    "body": "Est quod itaque suscipit quidem dolor dolores velit. Nihil voluptas placeat ex consequatur quasi.\n\nEst nulla cupiditate ad beatae rerum veritatis vel. Quia ut doloribus consequatur porro. Eligendi sit et dignissimos qui voluptatem magnam mollitia labore.\n\nLibero saepe praesentium et sed. Exercitationem error rerum sit inventore provident laborum. Fuga pariatur dolor reiciendis. Quibusdam corrupti commodi ut quo non laboriosam quia. Nihil sit iste sit optio voluptas repellendus exercitationem.",
    "published_at": "2018-01-25",
    "links": {
        "self": "https:\/\/sarala-demo.app\/api\/posts\/1"
    },
    "meta": {
        "copyright": "Copyright 2018 Example Corp."
    }
};

export const PaginatedPostsList = {
    "data_collection": true,
    "data": [
        {
            "id": "1",
            "type": "posts",
            "links": {
                "self": "https:\/\/sarala-demo.app\/api\/posts\/1"
            },
            "slug": "voluptates-laborum-non-voluptatem-ducimus-veniam-et",
            "title": "Voluptates laborum non voluptatem ducimus veniam et.",
            "subtitle": "Cumque aut laudantium repudiandae rem repellendus voluptatem. Sunt ipsa eum ea molestias.",
            "body": "Est quod itaque suscipit quidem dolor dolores velit. Nihil voluptas placeat ex consequatur quasi.\n\nEst nulla cupiditate ad beatae rerum veritatis vel. Quia ut doloribus consequatur porro. Eligendi sit et dignissimos qui voluptatem magnam mollitia labore.\n\nLibero saepe praesentium et sed. Exercitationem error rerum sit inventore provident laborum. Fuga pariatur dolor reiciendis. Quibusdam corrupti commodi ut quo non laboriosam quia. Nihil sit iste sit optio voluptas repellendus exercitationem.",
            "published_at": "2018-01-25"
        },
        {
            "id": "2",
            "type": "posts",
            "links": {
                "self": "https:\/\/sarala-demo.app\/api\/posts\/2"
            },
            "slug": "atque-nobis-maxime-voluptatem-voluptatem-labore",
            "title": "Atque nobis maxime voluptatem voluptatem labore.",
            "subtitle": "Eum sit aut ducimus dicta possimus. Quam voluptas consequatur aspernatur laborum corporis.",
            "body": "Omnis non sit voluptatem perspiciatis harum. Ad itaque dolores sunt distinctio. Sequi id et aliquid consequatur natus eum illum. Voluptatem natus velit vel et officiis molestiae molestiae voluptatem.\n\nCum voluptatem quam voluptatum dolores dolor corporis. Et fugiat expedita eum nisi corrupti voluptas. Magnam molestiae alias nulla dolores soluta nam. Est aut nihil tempore sed.\n\nVoluptas iusto eveniet adipisci alias voluptas ab. Fugit praesentium distinctio porro iure sit. Dolorem sit amet ab enim dolores mollitia sequi.",
            "published_at": "2018-02-01"
        },
        {
            "id": "3",
            "type": "posts",
            "links": {
                "self": "https:\/\/sarala-demo.app\/api\/posts\/3"
            },
            "slug": "velit-excepturi-et-eius",
            "title": "Velit excepturi et eius.",
            "subtitle": "Autem culpa dolores quis beatae rem. Qui rerum pariatur sed dolorem est rem pariatur.",
            "body": "Deleniti facere sed amet rerum. Fuga ut quia et et maxime. Ut deleniti quibusdam dolores pariatur et sit et.\n\nIpsum eos esse voluptas nihil maxime itaque. Sed rem repudiandae praesentium aut ullam. Dolores veniam qui et iusto.\n\nNostrum earum sed nobis aut accusantium velit. Corporis doloribus sit dicta. Rem odit non illum dolores. Distinctio dolores et qui sapiente est fugiat error. Voluptatum harum ullam et.",
            "published_at": "2018-01-17"
        },
        {
            "id": "4",
            "type": "posts",
            "links": {
                "self": "https:\/\/sarala-demo.app\/api\/posts\/4"
            },
            "slug": "ipsum-ut-ut-dolorem-qui-voluptas",
            "title": "Ipsum ut ut dolorem qui voluptas.",
            "subtitle": "Id enim dolores veniam consequatur. Sit perspiciatis deserunt ut reiciendis voluptas.",
            "body": "Reprehenderit esse porro sed quae voluptates et. Rem omnis et qui nemo. Sed mollitia voluptatem vero aspernatur ut nobis porro.\n\nVoluptas voluptatem molestiae tempora autem. Repudiandae dolor qui nisi. Saepe sunt veniam perferendis consequatur quisquam quo id.\n\nIusto ut libero ipsa quia sed unde architecto. Aliquam quia sint qui earum et. Architecto et accusamus sed impedit doloremque.",
            "published_at": "2018-02-27"
        }
    ],
    "meta": {
        "pagination": {
            "total": 10,
            "count": 4,
            "per_page": 4,
            "current_page": 1,
            "total_pages": 3
        }
    },
    "links": {
        "self": "https:\/\/sarala-demo.app\/api\/posts?=1",
        "first": "https:\/\/sarala-demo.app\/api\/posts?=1",
        "next": "https:\/\/sarala-demo.app\/api\/posts?=2",
        "last": "https:\/\/sarala-demo.app\/api\/posts?=3"
    }
};

export const PostWithAllNesterRelations = {
    "id": "1",
    "type": "posts",
    "slug": "voluptates-laborum-non-voluptatem-ducimus-veniam-et",
    "title": "Voluptates laborum non voluptatem ducimus veniam et.",
    "subtitle": "Cumque aut laudantium repudiandae rem repellendus voluptatem. Sunt ipsa eum ea molestias.",
    "body": "Est quod itaque suscipit quidem dolor dolores velit. Nihil voluptas placeat ex consequatur quasi.\n\nEst nulla cupiditate ad beatae rerum veritatis vel. Quia ut doloribus consequatur porro. Eligendi sit et dignissimos qui voluptatem magnam mollitia labore.\n\nLibero saepe praesentium et sed. Exercitationem error rerum sit inventore provident laborum. Fuga pariatur dolor reiciendis. Quibusdam corrupti commodi ut quo non laboriosam quia. Nihil sit iste sit optio voluptas repellendus exercitationem.",
    "published_at": "2018-01-25",
    "relationships": [
        "author",
        "tags",
        "comments"
    ],
    "author": {
        "data": {
            "email": "margret06@example.com",
            "id": "1",
            "links": {
                "self": "https://sarala-demo.app/api/users/1"
            },
            "name": "Heidi Hintz Jr.",
            "type": "users"
        },
        "links": {
            "related": "https://sarala-demo.app/api/posts/1/author",
            "self": "https://sarala-demo.app/api/posts/1/getRelations/author"
        }
    },
    "comments": {
        "data": [
            {
                "author": {
                    "data": {
                        "email": "reynold11@example.org",
                        "id": "11",
                        "links": {
                            "self": "https://sarala-demo.app/api/users/11"
                        },
                        "name": "Abdullah Grant",
                        "type": "users"
                    },
                    "links": {
                        "related": "https://sarala-demo.app/api/comments/1/author",
                        "self": "https://sarala-demo.app/api/comments/1/getRelations/author"
                    }
                },
                "body": "Nihil et quia tempora est quae nostrum velit ipsum. Nemo et aut maxime id.",
                "created_at": "2018-02-10",
                "id": "1",
                "links": {
                    "self": "https://sarala-demo.app/api/comments/1"
                },
                "relationships": [
                    "author"
                ],
                "type": "comments"
            },
            {
                "author": {
                    "data": {
                        "email": "manuela76@example.net",
                        "id": "12",
                        "links": {
                            "self": "https://sarala-demo.app/api/users/12"
                        },
                        "name": "Mr. Nathanial Maggio",
                        "type": "users"
                    },
                    "links": {
                        "related": "https://sarala-demo.app/api/comments/2/author",
                        "self": "https://sarala-demo.app/api/comments/2/getRelations/author"
                    }
                },
                "body": "Sint quaerat et ut delectus ratione id alias ab. Aut molestias ut dolores maiores ratione deserunt.",
                "created_at": "2018-02-10",
                "id": "2",
                "links": {
                    "self": "https://sarala-demo.app/api/comments/2"
                },
                "relationships": [
                    "author"
                ],
                "type": "comments"
            }
        ],
        "data_collection": true,
        "links": {
            "related": "https://sarala-demo.app/api/posts/1/comments",
            "self": "https://sarala-demo.app/api/posts/1/getRelations/comments"
        }
    },
    "tags": {
        "data": [
            {
                "id": "1",
                "links": {
                    "self": "https://sarala-demo.app/api/tags/1"
                },
                "name": "voluptates",
                "type": "tags"
            },
            {
                "id": "15",
                "links": {
                    "self": "https://sarala-demo.app/api/tags/15"
                },
                "name": "dolorum",
                "type": "tags"
            }
        ],
        "data_collection": true,
        "links": {
            "related": "https://sarala-demo.app/api/posts/1/tags",
            "self": "https://sarala-demo.app/api/posts/1/getRelations/tags"
        }
    },
    "links": {
        "self": "https://sarala-demo.app/api/posts/1"
    }
};
